@@ -355,7 +355,7 @@ class TestLinuxFedora_24_ppc64le(unittest.TestCase):
 	def test_returns(self):
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_registry()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_cpufreq_info()))
-		self.assertEqual(1, len(cpuinfo._get_cpu_info_from_lscpu()))
+		self.assertEqual(3, len(cpuinfo._get_cpu_info_from_lscpu()))
 		self.assertEqual(5, len(cpuinfo._get_cpu_info_from_proc_cpuinfo()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_sysctl()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_kstat()))
@@ -364,11 +364,14 @@ class TestLinuxFedora_24_ppc64le(unittest.TestCase):
 		self.assertEqual(1, len(cpuinfo._get_cpu_info_from_ibm_pa_features()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_sysinfo()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_cpuid()))
-		self.assertEqual(11, len(cpuinfo.get_cpu_info()))
+		self.assertEqual(14, len(cpuinfo.get_cpu_info()))
 
 	def test_get_cpu_info_from_lscpu(self):
 		info = cpuinfo._get_cpu_info_from_lscpu()
 
+		self.assertEqual('32 KB', info['l1_instruction_cache_size'])
+		self.assertEqual('64 KB', info['l1_data_cache_size'])
+
 		self.assertEqual('POWER8E (raw), altivec supported', info['brand'])
 
 	def test_get_cpu_info_from_ibm_pa_features(self):
@@ -398,6 +401,8 @@ class TestLinuxFedora_24_ppc64le(unittest.TestCase):
 		self.assertEqual('PPC_64', info['arch'])
 		self.assertEqual(64, info['bits'])
 		self.assertEqual(2, info['count'])
+		self.assertEqual('32 KB', info['l1_instruction_cache_size'])
+		self.assertEqual('64 KB', info['l1_data_cache_size'])
 		self.assertEqual('ppc64le', info['raw_arch_string'])
 		self.assertEqual(
 			['dss_2.02', 'dss_2.05', 'dss_2.06', 'fpu', 'lsd_in_dscr', 'ppr', 'slb', 'sso_2.06', 'ugr_in_dscr'],
