@@ -456,7 +456,7 @@ class TestLinuxUbuntu_16_04_X86_64(unittest.TestCase):
 	def test_returns(self):
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_registry()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_cpufreq_info()))
-		self.assertEqual(10, len(cpuinfo._get_cpu_info_from_lscpu()))
+		self.assertEqual(14, len(cpuinfo._get_cpu_info_from_lscpu()))
 		self.assertEqual(11, len(cpuinfo._get_cpu_info_from_proc_cpuinfo()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_sysctl()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_kstat()))
@@ -465,7 +465,7 @@ class TestLinuxUbuntu_16_04_X86_64(unittest.TestCase):
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_ibm_pa_features()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_sysinfo()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_cpuid()))
-		self.assertEqual(16, len(cpuinfo.get_cpu_info()))
+		self.assertEqual(20, len(cpuinfo.get_cpu_info()))
 
 	def test_get_cpu_info_from_lscpu(self):
 		info = cpuinfo._get_cpu_info_from_lscpu()
@@ -480,6 +480,11 @@ class TestLinuxUbuntu_16_04_X86_64(unittest.TestCase):
 		self.assertEqual(7, info['stepping'])
 		self.assertEqual(42, info['model'])
 		self.assertEqual(6, info['family'])
+
+		self.assertEqual('32 KB', info['l1_instruction_cache_size'])
+		self.assertEqual('32 KB', info['l1_data_cache_size'])
+		self.assertEqual('256 KB', info['l2_cache_size'])
+		self.assertEqual('3072 KB', info['l3_cache_size'])
 		self.assertEqual(
 			['acpi', 'aperfmperf', 'apic', 'arat', 'arch_perfmon', 'bts',
 			'clflush', 'cmov', 'constant_tsc', 'cx16', 'cx8', 'de', 'ds_cpl',
@@ -519,7 +524,7 @@ class TestLinuxUbuntu_16_04_X86_64(unittest.TestCase):
 		self.assertEqual((2800000000, 0), info['hz_advertised_raw'])
 		self.assertEqual((1901375000, 0), info['hz_actual_raw'])
 
-		self.assertEqual('3072 KB', info['l2_cache_size'])
+		self.assertEqual('3072 KB', info['l3_cache_size'])
 
 		self.assertEqual(7, info['stepping'])
 		self.assertEqual(42, info['model'])
@@ -555,7 +560,12 @@ class TestLinuxUbuntu_16_04_X86_64(unittest.TestCase):
 
 		self.assertEqual('x86_64', info['raw_arch_string'])
 
-		self.assertEqual('3072 KB', info['l2_cache_size'])
+		self.assertEqual('32 KB', info['l1_instruction_cache_size'])
+		self.assertEqual('32 KB', info['l1_data_cache_size'])
+
+		self.assertEqual('256 KB', info['l2_cache_size'])
+
+		self.assertEqual('3072 KB', info['l3_cache_size'])
 
 		self.assertEqual(7, info['stepping'])
 		self.assertEqual(42, info['model'])
